<?php

namespace App\Http\Controllers\Admin;

use App\Models\AdminRoleModel;
use App\Models\Department;
use App\Models\Device;
use App\Models\DeviceName;
use App\Models\InnerDevice;
use App\Models\Option;
use App\Models\Road;
use App\Models\Role;
use App\Models\Spec;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;

class InnerDeviceController extends BaseController
{
    protected $model;
    
    protected $device;

    protected $department;

    protected $model_name = '设备';

    protected $pre_uri = '/admin/InnerDevice/';

    protected $view_path = 'admin.inner-devices.';

    protected $redirect_index = '/admin/InnerDevice/index';

    public function __construct()
    {
        $this->model = new InnerDevice();
        $this->device = new Device();
    }

    public function index()
    {
        $options = $this->device->getDeviceOptions();
        $statuses = Option::get('inner_devices', 'status');
        list($model, $model_name, $pre_uri) = array($this->model, $this->model_name, $this->pre_uri);
        return view($this->view_path . 'index', compact('model', 'model_name','pre_uri', 'options', 'statuses'));
    }

    public function get(Request $request)
    {
        $items = $this->model->where('id', '>', 0)->with(['device', 'spec', 'device_name']);

        $tmp_items = collect(['number']);
        foreach($tmp_items as $tmp_item) {
            if($request->has($tmp_item) && !empty($request->input($tmp_item))) {
                $items = $items->where($tmp_item, 'like', '%' . $request->input($tmp_item) . '%');
            }
        }

        $select_items = collect(['device_id', 'device_name_id', 'spec_id', 'status']);
        foreach($select_items as $select_item) {
            if($request->has($select_item) && !empty($request->input($select_item))) {
                $items = $items->where($select_item, '=', $request->input($select_item));
            }
        }

        $items = $items->orderBy('updated_at', 'desc')->paginate();

        foreach ($items as $item) {
            $item->device_type = $item->device ? $item->device->name : '';
            $item->device_name_name = $item->device_name ? $item->device_name->name : '';
            $item->spec_name = $item->spec ? $item->spec->name : '';
            $item->status = $item->option ? '<div style="color: ' . $item->option->color . '">' . $item->option->name . '</div>' : '';
        }


        return response()->json(['code' => 0, 'message' => '', 'count' => $items->total(), 'data' => $items->items()]);
    }

    public function create()
    {
        list($model, $model_name, $pre_uri) = array($this->model, $this->model_name, $this->pre_uri);
        $options = $this->device->getDeviceOptions();
        $status_options = Option::get('inner_devices', 'status');
        return view($this->view_path . 'create', compact('model', 'model_name','pre_uri', 'options', 'status_options'));
    }

    public function transObject($items)
    {
        return json_decode(json_encode($items));
    }

    public function store(Request $request)
    {
        if(empty($request->input('data')) || !is_array($request->input('data'))) return back()->withErrors(['sg_error_info' => '数据错误']);
        $validator = $this->model->getValidator($request, 'store');
        if($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }
        $data = $request->input('data');
        $data['device_id'] = $request->input('device_id');
        $data['device_name_id'] = $request->input('device_name_id');
        $data['spec_id'] = $request->input('spec_id');
        $res = $this->model->create($data);
        if(empty($res)) return back()->withErrors(['sg_error_info' => '保存失败']);
        return redirect($this->pre_uri . 'create')->with(['sg_success_info' => '创建成功']);
    }

    public function edit(Request $request)
    {
        if(empty($request->input('id')) || empty($item = $this->model->find($request->input('id')))) return back()->withErrors(['sg_error_info' => '找不到要编辑的数据']);
        $options = $this->device->getDeviceOptions();
        $status_options = Option::get('inner_devices', 'status');
        list($model, $model_name, $pre_uri) = array($this->model, $this->model_name, $this->pre_uri);
        return view($this->view_path . 'edit', compact('model', 'model_name', 'pre_uri', 'item', 'options', 'status_options'));
    }

    public function update(Request $request)
    {
        if(empty($request->input('id')) || empty($item = $this->model->find($request->input('id')))) return back()->withErrors(['sg_error_info' => '找不到要编辑的数据']);
        if(empty($request->input('data')) || !is_array($request->input('data'))) return back()->withErrors(['sg_error_info' => '数据错误']);
        $validator = $this->model->getValidator($request, 'update');
        if($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }
        $data = $request->input('data');
        $data['device_id'] = $request->input('device_id');
        $data['device_name_id'] = $request->input('device_name_id');
        $data['spec_id'] = $request->input('spec_id');
        $res = $this->model->where('id', $request->input('id'))->update($data);
        if(!$res) return back()->withErrors(['sg_error_info' => '数据库保存失败！']);
        return back()->with(['sg_success_info' => '编辑成功']);
    }

    public function delete(Request $request)
    {
        if(empty($request->input('id')) || empty($item = $this->model->find($request->input('id')))) return response()->json(['status' => 'fail', 'info' => '找不到要删除的数据']);
        $res = $item->delete();
        if (!$res) return response()->json(['status' => 'fail', 'info' => '删除失败']);
        return response()->json(['status' => 'success', 'info' => '操作成功']);
    }

}
